# -*- coding: utf8 -*-

from datetime import date

from django import forms

from portailuser.fields import PortailUserField
from .models import Sondage


class ChoixForm(forms.Form):
    def __init__(self, sondage, donnees_post=None, **kwargs):
        self.bouton_presse = False

        # On construit la liste des données
        if donnees_post:
            donnees = []
            cpt = 1
            while ("choix_" + str(cpt)) in donnees_post:
                if ("moins_choix_" + str(cpt)) in donnees_post:
                    self.bouton_presse = True
                else:
                    donnees.append(donnees_post["choix_" + str(cpt)])
                cpt += 1

            if "plus" in donnees_post:
                self.bouton_presse = True
                donnees.append("")

            # Il ne faut pas passer un dictionnaire vide (sinon il sera ignoré)
            super(ChoixForm, self).__init__({"x": ""}, **kwargs)
            del self.data["x"]

        else:
            donnees = sondage.get_choix()
            super(ChoixForm, self).__init__(**kwargs)

        # On crée les champs de formulaire
        if donnees == []:
            donnees = ["", ""]

        if len(donnees) == 1:
            donnees.append("")

        cpt = 1
        limite = len(donnees) > 2
        for valeur in donnees:
            champ = forms.CharField(label="Choix " + str(cpt), required=False)
            champ.a_bouton_plus = False
            champ.a_bouton_moins = limite

            # Rentrée des valeurs :
            if donnees_post:
                # Dans les données “POST” (active la validation des champs)
                self.data["choix_" + str(cpt)] = valeur
            else:
                # Par valeur initiale
                champ.initial = valeur

            self.fields["choix_" + str(cpt)] = champ
            cpt += 1

        # Bouton “plus” sur le dernier champ
        champ.a_bouton_plus = True
        # Bouton “moins” s’il n’est pas tout seul
        champ.a_bouton_moins = len(donnees) > 2

    def donnees_entrees(self):
        donnees = []
        for ident_champ in sorted(self.cleaned_data.keys()):
            valeur = self.cleaned_data[ident_champ].strip()
            if not valeur:
                continue

            donnees.append(valeur)

        return donnees


class SondageForm(forms.ModelForm):
    def clean_date_fin(self):
        date_fin = self.cleaned_data["date_fin"]
        if date_fin <= date.today():
            raise forms.ValidationError("La date de fin doit être supérieure à la date actuelle.")
        return date_fin

    class Meta:
        model = Sondage
        fields = ("titre", "description", "date_fin", "choix_multiple", "resultats_masques", "anonyme")


class VotantsForm(forms.Form):
    user = PortailUserField()
